/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_AudioChannelBinding_h__
#define mozilla_dom_AudioChannelBinding_h__

#include "js/RootingAPI.h"
#include "jspubtd.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"
#include "mozilla/dom/Nullable.h"

namespace mozilla {
namespace dom {

class NativePropertyHooks;
class ProtoAndIfaceCache;

} // namespace dom
} // namespace mozilla

namespace mozilla {
namespace dom {


MOZ_BEGIN_ENUM_CLASS(AudioChannel, uint32_t)
  Normal,
  Content,
  Notification,
  Alarm,
  Telephony,
  Ringer,
  Publicnotification
MOZ_END_ENUM_CLASS(AudioChannel)

namespace AudioChannelValues {
extern const EnumEntry strings[8];
} // namespace AudioChannelValues


} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_AudioChannelBinding_h__
