/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsIDOMEvent.idl"

interface mozIDOMApplication;

[scriptable, builtinclass, uuid(453ae38a-8d8d-465f-a718-3f01240f8f75)]
interface nsIDOMMozApplicationEvent : nsIDOMEvent
{
  readonly attribute mozIDOMApplication application;

  [noscript] void initMozApplicationEvent(in DOMString aType,
                                          in boolean aCanBubble,
                                          in boolean aCancelable,
                                          in mozIDOMApplication aApplication);
};
