/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "domstubs.idl"

[scriptable, uuid(98575762-a936-4ecf-a226-b74c3a2981b4)]
interface nsIDOMSVGNumber : nsISupports
{ 
  attribute float value;
             // raises DOMException on setting
};




