/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_NativeOSFileInternalsBinding_h__
#define mozilla_dom_NativeOSFileInternalsBinding_h__

#include "js/RootingAPI.h"
#include "jspubtd.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"
#include "mozilla/dom/Nullable.h"

namespace mozilla {
namespace dom {

struct NativeOSFileReadOptionsAtoms;
class NativePropertyHooks;
class ProtoAndIfaceCache;

} // namespace dom
} // namespace mozilla

namespace mozilla {
namespace dom {

struct NativeOSFileReadOptions : public DictionaryBase
{
  Optional<Nullable<uint64_t>> mBytes;
  Optional<nsString> mEncoding;

  NativeOSFileReadOptions();

  explicit inline NativeOSFileReadOptions(const NativeOSFileReadOptions& aOther)
  {
    *this = aOther;
  }

protected:
  explicit inline NativeOSFileReadOptions(int )
  {
    // Do nothing here; this is used by our "Fast" subclass
  }

private:
  static bool
  InitIds(JSContext* cx, NativeOSFileReadOptionsAtoms* atomsCache);

public:
  bool
  Init(JSContext* cx, JS::Handle<JS::Value> val, const char* sourceDescription = "Value");

  bool
  Init(const nsAString& aJSON);

  bool
  ToObject(JSContext* cx, JS::MutableHandle<JS::Value> rval) const;

  void
  TraceDictionary(JSTracer* trc);

  void
  operator=(const NativeOSFileReadOptions& aOther);
};

namespace binding_detail {
struct FastNativeOSFileReadOptions : public NativeOSFileReadOptions
{
  inline FastNativeOSFileReadOptions()
    : NativeOSFileReadOptions(42)
  {
    // Doesn't matter what int we pass to the parent constructor
  }
};
} // namespace binding_detail


} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_NativeOSFileInternalsBinding_h__
